@@ -401,7 +401,7 @@ if ( aln_compare==1)pep_compare=0;
        if ( count==1)
           {
 	  fprintf (fp, "Number of seq: %d %d\n", SA->nseq,SA->nseq);
-	  for ( a=0; a< SA->nseq; a++) fprintf (fp, "%-15s %d %d\n", SA->name[a], strlen (SA->seq[a]), strlen (SA->seq[a]));
+	  for ( a=0; a< SA->nseq; a++) fprintf (fp, "%-15s %d %d\n", SA->name[a], (int)strlen (SA->seq[a]), (int)strlen (SA->seq[a]));
 	  }
 	      
        if (SA->nseq!=SB->nseq)
@@ -434,7 +434,7 @@ if ( aln_compare==1)pep_compare=0;
 
 	   if ( strlen ( SA->seq[a])!= strlen (SB->seq[a]))
 	       {
-	       fprintf ( fp, "DIFFERENCE TYPE 3: %s has != length in the 2 files (%d-%d)\n", SA->name[a],strlen ( SA->seq[a]), strlen (SB->seq[a]));
+		 fprintf ( fp, "DIFFERENCE TYPE 3: %s has != length in the 2 files (%d-%d)\n", SA->name[a],(int)strlen ( SA->seq[a]), (int)strlen (SB->seq[a]));
 	       f=1;
 	       }
 	   }
@@ -1163,10 +1163,10 @@ myexit (EXIT_SUCCESS);
 }
 
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
