@@ -78,6 +78,27 @@
 #define NON_VECTOR        23
 #define NON_PROFILE       24
 #define BOOTSTRAP         25
+
+#define HEADER            26
+#define NO_HEADER         27
+
+#define VERY_VERBOSE      28
+#define VERBOSE           29
+#define SHORT             30
+#define VERY_SHORT        31
+
+#define OVERLAP           32
+#define NO_OVERLAP        33
+
+#define PRINT             34
+#define NO_PRINT          35
+
+#define FREE_ALN              36
+#define DECLARE_ALN           37
+#define EXTRACT_ALN           38
+
+#define CLEAN                 39
+
 #define GOP               0
 #define GCP               1
 #define GEP               2
@@ -283,8 +304,25 @@
 #define URL "http://www.tcoffee.org"
 
 #define PERL_HEADER "#!/usr/bin/env perl"
+
+//Optimize the Score Computation in DP
+#define TC_SCORE_2(x,y) (SCORE_K*CL->M[Aln->seq_al[l_s[0][0]][x]-'A'][Aln->seq_al[l_s[1][0]][y]-'A']-SCORE_K*CL->nomatch) 
+#define TC_SCORE_N(x,y) ((CL->get_dp_cost)(Aln, pos, ns[0], l_s[0], x, pos, ns[1], l_s[1], y, CL))
+#define TC_SCORE(x,y)  ((CL->get_dp_cost==slow_get_dp_cost && CL->evaluate_residue_pair==evaluate_matrix_score && ns[0]+ns[1]==2 && x>=0 && j>=0)? (TC_SCORE_2(x,y)):(TC_SCORE_N(x,y)))
+
+#define NULL_2 NULL,NULL
+#define NULL_3 NULL_2,NULL
+#define NULL_4 NULL_2,NULL_2
+#define NULL_5 NULL_3,NULL_2
+#define NULL_6 NULL_4,NULL_2
+#define NULL_7 NULL_5,NULL_2
 /*               PROGRAM PATH                  */
 
+/********************************************/
+/*            SEQAN STUFF                   */
+/********************************************/
+#define SEQAN_TCOFFEE_4_TCOFFEE "seqan_tcoffee"
+
 /********************************************/
 /*            SEQUENCE ALIGNMENT            */
 /********************************************/
@@ -293,6 +331,7 @@
 #define CLUSTALW_4_TCOFFEE "clustalw"
 #define POA_4_TCOFFEE "poa"
 #define PROBCONS_4_TCOFFEE "probcons"
+#define PROBCONSRNA_4_TCOFFEE "probconsRNA"
 #define DIALIGNT_4_TCOFFEE "dialign-t"
 #define MAFFT_4_TCOFFEE "mafft"
 #define MUSCLE_4_TCOFFEE "muscle"
@@ -301,6 +340,7 @@
 #define KALIGN_4_TCOFFEE "kalign"
 #define AMAP_4_TCOFFEE "amap"
 #define PRODA_4_TCOFFEE "proda"
+#define CONSAN_4_TCOFFEE "sfold"
 
 
 /*New Methods*/
@@ -380,16 +420,16 @@ The format is as follow:
 the RGB values are used for the post-script generation, the html code is used in html documents.
 */
 /*               Identification    */           
-#define DATE "Fri Oct 26 17:01:36 2007"
+#define DATE "Fri Jun 6 17:32:56 WEST 2008"
 #define PROGRAM "T-COFFEE"
-#define VERSION "Version_5.31"
+#define VERSION "Version_5.72"
 #define AUTHOR "Cedric Notredame "
 #define DISTRIBUTION_ADDRESS "www.tcoffee.org/Packages/"
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
