@@ -157,6 +157,7 @@ int gotoh_pair_wise_lgp ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
 int test_pair_wise (Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 
 int glocal2_pair_wise (Alignment *A,int*ns, int **ls,Constraint_list *CL);
+int gotoh_pair_wise_lgp_sticky ( Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 int subop1_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL);
 int subop2_pair_wise ( Alignment *A, int *ns, int **ls, Constraint_list *CL);
 
@@ -327,7 +328,12 @@ int  node2seq_list (NT_node P, int *ns, int *ls);
 Alignment* delayed_tree_aln1 ( NT_node P,Alignment*A,Constraint_list *CL, int threshold);
 Alignment* delayed_tree_aln2 ( NT_node P,Alignment*A,Constraint_list *CL, int threshold);
 
+NT_node* tree2ao (NT_node LT, NT_node RT,Alignment *A, int nseq,Constraint_list *CL);//tree2align_order
 NT_node* tree_aln ( NT_node LT, NT_node RT, Alignment*A, int nseq, Constraint_list *CL);
+NT_node* local_tree_aln ( NT_node LT, NT_node RT, Alignment*A, int nseq, Constraint_list *CL);
+NT_node* seqan_tree_aln ( NT_node LT, NT_node RT, Alignment*A, int nseq, Constraint_list *CL);
+
+
 NT_node* tree_realn ( NT_node LT, NT_node RT, Alignment*A, int nseq, Constraint_list *CL);
 
 int split_condition (int nseq, int score, Constraint_list *CL);
@@ -498,7 +504,11 @@ int evaluate_aln_profile_score   (Constraint_list *CL, int s1, int r1, int s2, i
 
 int evaluate_profile_score                         ( Constraint_list *CL,Alignment *Prf1, int s1, int r1, Alignment *Prf2, int s2, int r2);
 int evaluate_cdna_matrix_score                     ( Constraint_list *CL, int s1, int r1, int s2, int r2);
+int evaluate_diaa_matrix_score                     ( Constraint_list *CL, int s1, int r1, int s2, int r2);
+int evaluate_monoaa_matrix_score                   ( Constraint_list *CL, int s1, int r1, int s2, int r2);
 int evaluate_matrix_score                          ( Constraint_list *CL, int s1, int r1, int s2, int r2);
+int evaluate_tm_matrix_score                          ( Constraint_list *CL, int s1, int r1, int s2, int r2);
+
 int evaluate_combined_matrix_score                 ( Constraint_list *CL, int s1, int r1, int s2, int r2);
 int evaluate_physico_score                         ( Constraint_list *CL, int s1, int r1, int s2, int r2);
 int residue_pair_non_extended_list                 ( Constraint_list *CL, int s1, int r1, int s2, int r2);
@@ -507,7 +517,7 @@ int residue_pair_extended_list4rna1                 ( Constraint_list *CL, int s
 int residue_pair_extended_list4rna2                 ( Constraint_list *CL, int s1, int r1, int s2, int r2);
 int residue_pair_extended_list4rna3                 ( Constraint_list *CL, int s1, int r1, int s2, int r2);
 int residue_pair_extended_list4rna4                 ( Constraint_list *CL, int s1, int r1, int s2, int r2);
-int residue_pair_extended_list4rna                 ( Constraint_list *CL, Constraint_list *R, int s1, int r1, int s2, int r2);
+int residue_pair_extended_list4rna                  ( Constraint_list *CL, Constraint_list *R, int s1, int r1, int s2, int r2);
 
 int residue_pair_extended_list                     ( Constraint_list *CL, int s1, int r1, int s2, int r2);
 int residue_pair_extended_list_g_coffee_quadruplet ( Constraint_list *CL, int s1, int r1, int s2, int r2);
@@ -586,6 +596,7 @@ int ** combine_two_matrices ( int **mat1, int **mat2);
 /*                                                                                           */
 /*********************************************************************************************/
 float  sum_pair ( Alignment*A,char *mat_name, int gap_op, int gap_ext);
+int lat_sum_pair (Alignment *A, char *mat);
 int ** show_pair(int istart, int iend, int jstart, int jend, int *seqlen_array, char **seq_array, int dna_ktup, int dna_window, int dna_wind_gap, int dna_signif,int prot_ktup, int prot_window,int prot_wind_gap,int prot_signif, int nseqs,int dnaflag, int max_aa, int max_aln_length  );
 /*By convention, 0: START, 1: END*/
 
@@ -754,10 +765,10 @@ int **pavie_seq2trained_pavie_mat(Sequence *S, char *param);
 int pavie_pair_wise (Alignment *A,int *ns, int **l_s,Constraint_list *CL );
 Sequence *pavie_seq2noisy_seq (Sequence *S, int val,char *subst); 
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
