@@ -3,6 +3,7 @@
 #include <math.h>
 #include <stdarg.h>
 #include <ctype.h>
+#include <string.h>
 
 #include "io_lib_header.h"
 #include "util_lib_header.h"
@@ -1966,7 +1967,7 @@ static int basePair(char x, char y)
 	    }
 	}
     }
-  return (int)mat[x][y];
+  return (int)mat[(int)x][(int)y];
 }
   
   
@@ -2075,7 +2076,7 @@ static int backtrack(int i, int j, int **numBasePairs,char *S, char *paren, int
      else 
        return 0;
    }  
-}   
+   return 0;}   
 
 int count;
 char * rna_struc2rna_lib ( char *seq_name, char *seq, char *name)
@@ -2123,10 +2124,10 @@ int display_rna_ss ( int n, char *seq, char *st, FILE *fp)
   return n;
 }
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
