@@ -367,7 +367,8 @@ int viterbi_pair_wise (Alignment *A,int*ns, int **ls,Constraint_list *CL)
   
   A->pos=aln2pos_simple( A, -1, ns, ls);
   
-  H=define_mnm_model (CL);
+  //  H=define_mnm_model (CL);
+  H=define_two_mat_model (CL);
   
   l1=strlen (A->seq_al[ls[0][0]]);
   l2=strlen (A->seq_al[ls[1][0]]);
@@ -2510,10 +2511,10 @@ MatState* viterbiL_hmm (Alignment *A,int *ns, int **ls, Hmm *H, Constraint_list
 /*	*/
 /*********************************COPYRIGHT NOTICE**********************************/
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
