@@ -121,6 +121,44 @@ Alignment* get_aln_type (Alignment *A)
 	      }
 	  return A;
 	}
+
+
+
+char *unset_mode ()
+{
+  return set_mode (UNSET, NULL);
+}
+char *store_mode (char *val)
+{
+  return set_mode (SET, val);
+}
+char *retrieve_mode ()
+{
+  return set_mode (GET,NULL);
+}
+char *set_mode (int mode, char *val)
+{
+  static char type[100];
+  if (mode==SET)
+    {
+      if (!val)printf_exit (EXIT_FAILURE, stderr, "Error:  programme mode unset in io_func.c:set_seq_type");
+      sprintf ( type,"%s", val);
+    }
+  else if ( mode==GET)
+    {
+      ;
+    }
+  else if ( mode==UNSET)
+    {
+      type[0]='\0';
+    }
+  else
+    {
+      printf_exit (EXIT_FAILURE, stderr, "Error: unknown mode in function io_func.c:set_seq_type, use SET, GET or UNSET");
+    }
+  return type;
+}
+/************************************************************/
 char *unset_seq_type ()
 {
   return set_seq_type (UNSET, NULL);
@@ -155,42 +193,27 @@ char *set_seq_type (int mode, char *val)
     }
   return type;
 }
+char * get_array_type (int n, char **seq)
+{
+  char *buf, *buf2;
+  int a, tot=0;
+  buf2=vcalloc ( 100, sizeof (char));
+		 
+  
+  for ( tot=0,a=0; a<n; a++)tot+=strlen (seq[a]);
+  buf=vcalloc (tot+1, sizeof (char));
+  for ( a=0; a<n; a++)strcat (buf, seq[a]);
+  sprintf ( buf2, "%s", get_string_type(buf));
+  vfree (buf);
+  return buf2;
+}
 Sequence *get_sequence_type (Sequence *S)
-        {
-	int a;
-	char *buf;
-	int tot;
+{
+  if ( !S) return NULL;
+  else sprintf ( S->type, "%s", get_array_type (S->nseq, S->seq));
+  return S;
+}
 
-	for ( tot=0,a=0; a< S->nseq; a++)tot+=strlen (S->seq[a]);
-	buf=vcalloc (tot+1, sizeof (char));
-	for ( a=0; a<S->nseq; a++)strcat (buf, S->seq[a]);
-	sprintf ( S->type, "%s", get_string_type(buf));
-	vfree (buf);
-	return S;
-	}
-Sequence *get_sequence_type_old (Sequence *S)
-        {
-	int a;
-	int protein=0,  dna=0;
-	char *type;
-	
-	for ( a=0; a< S->nseq; a++)
-	    {
-	     
-	    type=get_string_type (S->seq[a]);
-	    
-	    if ( strm (type, "DNA"))dna++;
-	    else if strm ( type, "PROTEIN")protein++;
-	    vfree(type);
-	    }
-	
-
-	if ( protein==0 && dna==0);
-	else if ( dna>protein )sprintf ( S->type, "DNA");
-	else if ( protein>dna)sprintf ( S->type, "PROTEIN");
-	else sprintf ( S->type, "PROTEIN_DNA");
-	return S;
-	}
 
 void get_sequence (char *seq_file,int *NSEQ, char ***SEQ, char ***SN, int **sl, int *min, int *max)
 	{
@@ -299,7 +322,7 @@ int ** read_matrice (char *mat_name_in)
 	else if (strm(mat_name, "rbeta_mat" ))vector=rbeta_mat;
 	else if (strm(mat_name, "ralpha_mat" ))vector=ralpha_mat;
 	else if (strm(mat_name, "rcoil_mat" ))vector=rcoil_mat;
-	
+	else if (strm (mat_name, "jtttm250mt"))vector=jtttm250mt;
 
 	/*Header Matrices*/
 	if(vector)
@@ -400,6 +423,21 @@ int ** read_matrice (char *mat_name_in)
 	      }
 	  }
 	
+	/*Correct for RNA: Add the U cost*/
+	for (b=0; b<l; b++)
+	  {
+	    
+	    matrix2['U'-'A'][toupper(AA[b])-'A']=matrix2['T'-'A'][toupper(AA[b])-'A'];
+	    matrix2[toupper(AA[b])-'A']['U'-'A']=matrix2[toupper(AA[b])-'A']['T'-'A'];
+	    matrix2['U'-'A'][toupper(AA[b])-'A']=matrix2['t'-'A'][tolower(AA[b])-'A'];
+	    matrix2[tolower(AA[b])-'A']['u'-'A']=matrix2[tolower(AA[b])-'A']['t'-'A'];
+					
+	  }
+	matrix2['U'-'A']['U'-'A']=matrix2['T'-'A']['T'-'A'];
+	matrix2['u'-'A']['U'-'A']=matrix2['t'-'A']['T'-'A'];
+	matrix2['U'-'A']['u'-'A']=matrix2['T'-'A']['t'-'A'];
+	matrix2['u'-'A']['u'-'A']=matrix2['t'-'A']['t'-'A'];
+	
 	free_int (matrice, -1);
 	return (matrix2);
 
@@ -1314,10 +1352,10 @@ int       output_seq_reliability_ascii     ( Alignment *B,Alignment *S, char *na
 }
   
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
