@@ -78,6 +78,27 @@
 #define NON_VECTOR        23
 #define NON_PROFILE       24
 #define BOOTSTRAP         25
+
+#define HEADER            26
+#define NO_HEADER         27
+
+#define VERY_VERBOSE      28
+#define VERBOSE           29
+#define SHORT             30
+#define VERY_SHORT        31
+
+#define OVERLAP           32
+#define NO_OVERLAP        33
+
+#define PRINT             34
+#define NO_PRINT          35
+
+#define FREE_ALN              36
+#define DECLARE_ALN           37
+#define EXTRACT_ALN           38
+
+#define CLEAN                 39
+
 #define GOP               0
 #define GCP               1
 #define GEP               2
@@ -283,6 +304,18 @@
 #define URL "http://www.tcoffee.org"
 
 #define PERL_HEADER "#!/usr/bin/env perl"
+
+//Optimize the Score Computation in DP
+#define TC_SCORE_2(x,y) (SCORE_K*CL->M[Aln->seq_al[l_s[0][0]][x]-'A'][Aln->seq_al[l_s[1][0]][y]-'A']-SCORE_K*CL->nomatch) 
+#define TC_SCORE_N(x,y) ((CL->get_dp_cost)(Aln, pos, ns[0], l_s[0], x, pos, ns[1], l_s[1], y, CL))
+#define TC_SCORE(x,y)  ((CL->get_dp_cost==slow_get_dp_cost && CL->evaluate_residue_pair==evaluate_matrix_score && ns[0]+ns[1]==2 && x>=0 && j>=0)? (TC_SCORE_2(x,y)):(TC_SCORE_N(x,y)))
+
+#define NULL_2 NULL,NULL
+#define NULL_3 NULL_2,NULL
+#define NULL_4 NULL_2,NULL_2
+#define NULL_5 NULL_3,NULL_2
+#define NULL_6 NULL_4,NULL_2
+#define NULL_7 NULL_5,NULL_2
 typedef struct
     {
     char *mode;
@@ -335,9 +368,11 @@ struct Template
 {
   char seq_type[10];
   struct X_template *P;
+  struct X_template *F;
   struct X_template *S;
   struct X_template *R;
   struct X_template *G;
+  
   struct X_template *RB;
 };
 typedef struct Template Template;
@@ -348,7 +383,8 @@ struct X_template
   char template_type[FILENAMELEN+1];
   char template_name[FILENAMELEN+1];
   char template_file[FILENAMELEN+1];
-  struct P_template *VP;
+  struct P_template *VP; 
+  struct F_template *VF;
   struct S_template *VS;
   struct R_template *VR;
   struct G_template *VG;
@@ -363,6 +399,13 @@ struct P_template
 };
 typedef struct P_template P_template;
 
+struct F_template
+{
+  int l;
+};
+typedef struct F_template F_template;
+
+
 struct S_template
 {
   Sequence *S;
@@ -499,10 +542,16 @@ Color;
 Sequence * fill_sequence_struc ( int nseq, char **sequences, char **seq_name);
 Sequence * cw_read_sequences ( char *seq_name);
 Sequence * get_sequence_type (Sequence *S);
+char     * get_array_type (int n, char **s);
 Alignment* get_aln_type (Alignment *A);
 
 char     * get_string_type   (char *string);
 
+char *store_mode (char *val);
+char *retrieve_mode ();
+char *unset_mode ();
+char *set_mode (int mode, char *val);
+
 char *store_seq_type (char *val);
 char *retrieve_seq_type ();
 char *unset_seq_type ();
@@ -669,6 +718,8 @@ void 		* ckvrealloc(void *,size_t);
 void 		ckfree(void *);
 
 int readseqs(char *saga_file,char ***SAGA_SEQ, char*** SAGA_NAMES, int ***SAGA_LEN) ;/*first_seq is the #no. of the first seq. to read */
+
+
 typedef struct treesim{
   float w;
   float uw;
@@ -678,8 +729,9 @@ typedef struct treesim{
   float max_uw;
   float max_d;
   
+  int n;//n nodes;
+  int nseq;// nseq in the common subset
     }Tree_sim;
-
 typedef struct tnode *NT_node;
 
 typedef struct tnode{
@@ -694,8 +746,8 @@ typedef struct tnode{
   int seq;
   int maxnseq;
   int nseq;
-  int *lseq;
-  int *lseq2;
+  int *lseq; //contains a list of the sequences
+  int *lseq2;//contains a coded version of the node: 10010101
   int *idist;//contains distances to the root, in nodes
   int *ldist;//contains real distances *1000;
   float dist;
@@ -711,6 +763,19 @@ typedef struct tnode{
   char *seqal;
   int index;
     }Treenode;
+
+typedef struct split_struc Split;
+
+typedef struct split_struc{
+  char *split;
+  int n;
+  int tot;
+  float score;
+  char **tlist;//Not used yet
+  Sequence *S;
+  NT_node *L;
+}Split_struc;
+
 NT_node main_prune_tree ( NT_node T, Sequence *S);
 NT_node prune_tree ( NT_node T, Sequence *S);
 /*********************************************************************/
@@ -739,6 +804,11 @@ int main_compare_cog_tree (NT_node T1, char *cogfile);
 int main_compare_aln_tree (NT_node T1, Alignment *A, FILE *fp);
 int compare_aln_tree (NT_node T, Alignment *A, int *n, FILE *fp);
 
+int main_compare_splits (NT_node T1, NT_node T2, char *mode, FILE *fp);
+Tree_sim * tree_cmp( NT_node T1, NT_node T2);
+NT_node tree_scan (Alignment *A,NT_node RT, char *pscan, char *ptree);
+
+
 NT_node main_compare_trees ( NT_node T1, NT_node T2, FILE *fp);
 float compare_trees ( NT_node T1, NT_node T2, int nseq, int mode);
 float search_node ( NT_node B, NT_node T, int nseq, int mode);
@@ -766,6 +836,7 @@ Alignment * filter_aln4tree (Alignment *A, int n,int fg,char* mode);
 /*                                                                   */
 /*                                                                   */
 /*********************************************************************/
+int  tree2star_nodes (NT_node R, int n_max);
 NT_node aln2tree (Alignment *A);
 NT_node reset_boot_tree ( NT_node R, int n);
 NT_node reset_dist_tree ( NT_node R, float n);
@@ -788,11 +859,14 @@ void clear_tree (NT_node T);
 int display_leaf ( NT_node T, FILE *fp);
 int display_leaf_below_node ( NT_node T, FILE *fp);
 NT_node display_leaf_nb (NT_node T, int n, FILE *fp, char *name);
+NT_node display_splits (NT_node T, int n, FILE *fp, char *name);
+int tree2split_list (NT_node T, int nseq, int **split_list, int *n);
 
 NT_node reroot_tree ( NT_node TREE, NT_node T);
 NT_node straighten_tree ( NT_node P, NT_node C, float new_dist);
 NT_node unroot_tree ( NT_node T);
 FILE* print_tree ( NT_node T,char *format, FILE *fp);
+int print_newick_tree ( NT_node T, char *name);
 FILE * rec_print_tree ( NT_node T, FILE *fp);
 
 
@@ -810,7 +884,9 @@ NT_node new_get_node (NT_node T, FILE *fp);
 
 
 NT_node** simple_read_tree(char *treefile);
+void free_read_tree (NT_node **BT);
 NT_node** read_tree(char *treefile, int *nnodes,int nseq, char **seq_names);
+FILE * create_linear_tree ( char **name, int n, FILE *fp);
 FILE * create_tree(NT_node ptree, NT_node parent,int *numseq,int  *ntotal,int  *nnodes,NT_node **lu, FILE *fp);
 NT_node declare_tree_node (int nseq);
 void set_info(NT_node p, NT_node parent, int pleaf, char *pname, float pdist, float bootstrap);
@@ -830,20 +906,29 @@ float tree2tot_dist ( NT_node T, int mode);
 int tree2n_branches(NT_node T, int mode);
 int **display_tree_from_node (NT_node T, int up, int down, int **array);
 NT_node tree2node ( char *name, NT_node T);
+NT_node tree2root ( NT_node T);
 int new_tree_sort ( char *name, NT_node T);
 
 
-
+NT_node split2tree ( NT_node RT,Sequence *LIST, char *param);
 NT_node * read_tree_list (Sequence *S);
-int treelist2groups (Sequence *S, Sequence *ST);
+
+int count_groups( Sequence *S, char *s);
+
+Split ** count_splits( NT_node RT, Sequence *S, char *s);
+
+int treelist2groups (Sequence *S, Sequence *ST, char *depth);
 int treelist2splits (Sequence *S, Sequence *ST);
-int treelist2leafgroup ( Sequence *S, Sequence *TS);
+int treelist2leafgroup ( Sequence *S, Sequence *TS, char *taxon);
 int ***tree2dist ( NT_node T, Sequence *S, int ***d);
 int treelist2lti ( Sequence *S, Sequence *TS, char *nb);
 
 float simple_tree_cmp (NT_node T1, NT_node T2,Sequence *S, int mode);
 
 int treelist2dmat ( Sequence *S);
+NT_node new_declare_tree_node ();
+int count_tree_groups( Sequence *LIST, char *group_file);
+int node_sort ( char *name, NT_node T);
 /* General purpose header file - rf 12/90 */
 
 #ifndef _H_general
@@ -865,10 +950,10 @@ typedef int Boolean;			/* Is already defined in THINK_C */
 
 #endif /* ifndef _H_general */
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
