@@ -505,7 +505,7 @@ double ***pavie_seq2pavie_fmat (Sequence *S,double *gop, double *gep, char **mat
 	  list=declare_int (S->nseq*S->nseq, 2);
 	  
 	  m=S->nseq-exclude_id;
-	  for (a=0,tot=0, a<0; a<m; a++)
+	  for (a=0; a<m; a++)
 	    for ( b=a+exclude_id; b<S->nseq; b++)
 	      {
 		if ( sim[a][b]>sample_size)
@@ -877,6 +877,7 @@ int pavie_score (char *s0,int p0, char *s1,int p1,char **mat_file, double *gop,
     static char *cmat;
     static int  ***mat;
     static int use_age;
+    static int mchscore=-1;
     
     int l0, l1, c0, c1;
     int a, score=0;
@@ -886,8 +887,12 @@ int pavie_score (char *s0,int p0, char *s1,int p1,char **mat_file, double *gop,
 	strget_param ( param, "_AGECHANNEL", "-1", "%d", &use_age);
 
       }
-   
+    if (mchscore==-1)
+      {
+	strget_param (param, "_MCHSCORE", "0", "%d", &mchscore);
 	
+      }
+    
     if ( !cmat || !mat_file || !strm (cmat, mat_file[0]))
       {
 	if ( !cmat)cmat=vcalloc ( 100, sizeof (char));
@@ -903,28 +908,48 @@ int pavie_score (char *s0,int p0, char *s1,int p1,char **mat_file, double *gop,
     
     l0=(s0)?strlen (s0)/nch:0;
     l1=(s1)?strlen (s1)/nch:0;
+
+    if (mchscore==0);
+    else if (mchscore==1) score=999999;
+    else if (mchscore==2)score=-9999999;
+    else 
+      {
+	HERE ("Error: mchscore >2 [FATAL]\n");
+	exit (EXIT_FAILURE);
+      }
     for ( a=0; a< nch; a++)
       {
+	int s;
 	c0=(s0)?s0[l0*a+p0]-'A':p0;
 	c1=(s1)?s1[l1*a+p1]-'A':p1;
-	if ( c0==GAP_CODE)score+=(gep[a]!=0)?gep[a]:mat[a][c1][GAP_CODE];
-	else if ( c1==GAP_CODE)score+=(gep[a]!=0)?gep[a]:mat[a][c0][GAP_CODE];
-	else score+=mat[a][c0][c1];
+	if ( c0==GAP_CODE)s=(gep[a]!=0)?gep[a]:mat[a][c1][GAP_CODE];
+	else if ( c1==GAP_CODE)s=(gep[a]!=0)?gep[a]:mat[a][c0][GAP_CODE];
+	else s=mat[a][c0][c1];
+
+	if (mchscore==0)score+=s;
+	else if (mchscore==1)score=MIN(s, score);
+	else if (mchscore==2)score=MAX(s, score);
+	
+
       }
     
     if ( use_age>0 && s0 && s1)
       {
-
+	
 	int a0, a1;
+	int s;
 	
 	a0=s0[strlen(s0)+1];
 	a1=s1[strlen(s1)+1];
 	
 	a0+=p0;
 	a1+=p1;
-	score+=use_age*FABS((a0-a1))*-1;
-      }
+	s=use_age*FABS((a0-a1))*-1;
 	
+	if (mchscore==0)score+=s;
+	else if (mchscore==1)score=MIN(s, score);
+	else if (mchscore==2)score=MAX(s, score);
+      }
 	
 	
     score*=factor;
@@ -1356,10 +1381,10 @@ Alignment* pavie_seq2pavie_msa ( Sequence *S, char *mat_in, char *mode)
   return A;
 }
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
