@@ -53,12 +53,14 @@ Constraint_list * declare_constraint_list ( Sequence *S, char *name, int **L, in
     CL->Prot_Blast=vcalloc ( 1, sizeof ( Blast_param));
     CL->DNA_Blast=vcalloc ( 1, sizeof ( Blast_param));
     CL->Pdb_Blast=vcalloc ( 1, sizeof ( Blast_param));
-    
+    CL->TC=vcalloc (1, sizeof (TC_param));
+  
     return CL;
     }
 
 Constraint_list *free_constraint_list4lib_computation (Constraint_list *CL)
 {
+  if (!CL)return NULL;
   
   free_int (CL->L, -1);
   free_int (CL->M, -1);
@@ -212,6 +214,8 @@ Constraint_list *copy_constraint_list (Constraint_list *CL, int mode)
       NCL->Prot_Blast=(mode==HARD_COPY)?duplicate_blast_param ( CL->Prot_Blast):CL->Prot_Blast;
       NCL->DNA_Blast =(mode==HARD_COPY)?duplicate_blast_param ( CL->DNA_Blast):CL->DNA_Blast;
       NCL->Pdb_Blast =(mode==HARD_COPY)?duplicate_blast_param ( CL->Pdb_Blast):CL->Pdb_Blast;
+      NCL->TC =(mode==HARD_COPY)?duplicate_TC_param ( CL->TC):CL->TC;
+      
     /*Split parameters*/
       NCL->split=CL->split;
       NCL->split_nseq_thres= CL->split_nseq_thres;
@@ -330,7 +334,8 @@ Sequence *free_constraint_list (Constraint_list *CL)
 	if ( CL->Prot_Blast             ==pCL->Prot_Blast              )CL->Prot_Blast=NULL;
 	if ( CL->DNA_Blast              ==pCL->DNA_Blast               )CL->DNA_Blast=NULL;
 	if ( CL->Pdb_Blast              ==pCL->Pdb_Blast               )CL->Pdb_Blast=NULL;
-	if ( CL->seq_for_quadruplet     ==pCL->seq_for_quadruplet       )CL->seq_for_quadruplet=NULL;
+	if ( CL->seq_for_quadruplet     ==pCL->seq_for_quadruplet      )CL->seq_for_quadruplet=NULL;
+	if ( CL->TC                      ==pCL->TC                       )CL->TC=NULL;
 	
       }
 
@@ -371,7 +376,8 @@ Sequence *free_constraint_list (Constraint_list *CL)
     if ( CL->Prot_Blast)free_blast_param ( CL->Prot_Blast);
     if ( CL->DNA_Blast) free_blast_param ( CL->DNA_Blast);
     if ( CL->Pdb_Blast) free_blast_param ( CL->Pdb_Blast);
-       
+    if ( CL->TC) free_TC_param ( CL->TC);
+    
     if (CL->seq_for_quadruplet)vfree (CL->seq_for_quadruplet);
 
     vfree(CL);
@@ -429,7 +435,24 @@ Moca * free_moca ( Moca *m)
 	vfree ( m);
 	return NULL;
       }
-
+/************************************************************************/
+/*                                                                      */
+/*            TC_param Functions                                            */
+/*                                                                      */
+/*                                                                      */
+/************************************************************************/
+TC_param * duplicate_TC_param ( TC_param*B)
+{
+  TC_param *N;
+  N=vcalloc (1, sizeof ( TC_param));
+  memcpy(B, N, sizeof(TC_param));
+  return N;
+  }
+TC_param * free_TC_param ( TC_param*B)
+{
+  vfree (B);
+  return NULL;
+}
 /************************************************************************/
 /*                                                                      */
 /*            Blast_param Functions                                            */
@@ -853,8 +876,10 @@ Alignment *declare_Alignment ( Sequence *S)
 	  [x][0]= which is the xth seq of aln
 	  [x][1]= how many deleted residues before the first one
 	*/
-
+	
+	
 	LA=vcalloc (1, sizeof ( Alignment));
+	aln_stack (LA, DECLARE_ALN);
 	if ( S==NULL)
 	    {
 	    LA->declared_len=MAX_LEN_ALN;
@@ -969,14 +994,62 @@ Alignment * realloc_alignment2 ( Alignment *A, int n_nseq, int n_len)
 	return A;
 	}
 
+
+long aln_stack (Alignment *A, int mode)
+{
+  static long *list;
+  static int size;
+  static int max_size;
+  
+  
+  if (A==NULL) return 0;
+  else if ( mode==DECLARE_ALN)
+    {
+      if ( size==max_size)
+	{
+	  max_size+=1000;
+	  list=vrealloc (list, max_size*sizeof (long));
+	}
+      list[size++]=(long)A;
+      return 0;
+    }
+  else if (mode==FREE_ALN)
+    {
+      int a, b;
+      for (a=0; a<size; a++)
+	{
+	  if (list[a]==(long)A)
+	    {
+	      for (b=a+1; b<size;b++)
+		{
+		  list[b-1]=list[b];
+		}
+	      list[b-1]=0;
+	      size--;
+	      return 1;
+	    }
+	}
+      return 0;
+    }
+  else if ( mode==EXTRACT_ALN)
+    {
+      return list[size--];
+    }
+  else
+    {
+      printf_exit (EXIT_FAILURE, stderr, "ERROR: Unknown mode for aln_stack");
+      return 0;
+    }
+}
+		 
 Sequence* free_aln ( Alignment *LA){ return free_Alignment(LA);}
 Sequence* free_Alignment ( Alignment *LA)
 	{
 	  /* Does not free the A->S field (sequences of A)*/
 	
 	  Sequence *S;
-	 	  
-	  if ( LA==NULL){return NULL;}
+	  //aln_stack checks the alignment has not already been freed
+	  if ( LA==NULL || !aln_stack(LA,FREE_ALN)){return NULL;}
 	  
 	  S=LA->S;
 	  free_char ( LA->file, -1);
@@ -1140,8 +1213,8 @@ void * vmalloc ( size_t size)
 	    
 	    if ( x==NULL)
 		{
-		crash ( "\nFAILED TO ALLOCATE REQUIRED MEMORY (vmalloc)\n");
-		return NULL;
+		  printf_exit (EXIT_FAILURE,stderr, "\nFAILED TO ALLOCATE REQUIRED MEMORY (vmalloc)\n");
+		  
 		}
 	    else
 	      {
@@ -1154,7 +1227,7 @@ void * vmalloc ( size_t size)
 		return x;
 	      }
 	    }
-	}
+	return NULL;}
 
 
 
@@ -1708,10 +1781,10 @@ Fname *free_fname ( Fname *F)
    return NULL;
    }
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
