@@ -9,6 +9,18 @@
 #include "define_header.h"
 #include "dp_lib_header.h"
 
+
+
+
+
+
+/*******************************************************************************/
+/*                idscore_pairseq: measure the % id without delivering thze aln*/                                                   
+/*                                                                             */
+/*	makes DP between the the ns[0] sequences and the ns[1]                 */
+/*                                                                             */
+/*	for MODE, see the function  get_dp_cost                                */
+/*******************************************************************************/
 int idscore_pairseq (char *s1, char *s2, int gop, int gep, int **m, char *comp_mode)
 {
   int **I, **D, **M, *P;
@@ -136,7 +148,6 @@ int idscore_pair_wise (Alignment *A,int*ns, int **l_s,Constraint_list *CL)
   A->score_aln=A->score=idscore_pairseq (A->seq_al[l_s[0][0]], A->seq_al[l_s[1][0]], CL->gop, CL->gep,CL->M, "sim3");
   return A->score_aln;
 }
-
 int dp_max (int *trace, int n, ...);
 int dp_max (int *trace, int n, ...)
 {
@@ -163,9 +174,48 @@ int dp_max (int *trace, int n, ...)
 	    }
 	}
     }
-  va_end (ap);
+ 
   return best_v;
 }
+int is_tied (int *trace, int n, ...);
+int is_tied(int *trace, int n, ...)
+{
+  va_list ap;
+  int a, v, t, best_v=0;
+  int nties=0;
+  
+  va_start (ap, n);
+  for (a=0; a< n; a++)
+    {
+      t=va_arg (ap, int);
+      v=va_arg (ap, int);
+
+      if (a==0)
+	{
+	  best_v=v;
+	  trace[0]=t;
+	}
+      else
+	{
+	  if (v>best_v)
+	    {
+	      best_v=v;
+	      trace[0]=t;
+	    }
+	}
+    }
+  va_end(ap);
+  va_start (ap,n);
+  for (a=0; a<n; a++)
+    {
+      t=va_arg (ap, int);
+      v=va_arg (ap, int);
+      if (v==best_v && trace[0]!=t)
+	nties++;
+    }
+  va_end (ap);
+  return nties;
+}
 
 void display_mat (int **M, int l1, int l2, char *title);
 void display_mat (int **M, int l1, int l2, char *title)
@@ -398,12 +448,15 @@ int gotoh_pair_wise_lgp ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
   int I, J;
   int M1, I1, D1, LEN;
   char **al, *char_buf, **aln;
-  int **pos0;
+  int **pos0, **pos;
+  Alignment *Aln;
   
   int gop[2], gcp[2], gep[2];
   static int ***gpl, ***t, ***m;
   static int max_li, max_lj;
   
+  
+
   //gotoh_pair_wise ( A, ns, l_s,CL);
   //ungap_sub_aln (A, ns[0], l_s[0]);
   //ungap_sub_aln (A, ns[1], l_s[1]);
@@ -426,14 +479,19 @@ int gotoh_pair_wise_lgp ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
     {
       free_arrayN((void**)t, 3);
       free_arrayN((void**)m, 3);
+
      
       max_li=li;
       max_lj=lj;
       t=declare_arrayN(3, sizeof (int),n, max_li+1, max_lj+1);
       m=declare_arrayN(3, sizeof (int),n, max_li+1, max_lj+1);
+      
     }
   pos0=aln2pos_simple ( A,-1, ns, l_s);
  
+  //Compatibility with Macro
+  Aln=A;
+  pos=pos0;
   
   for (j=1; j<=lj; j++)
     {
@@ -465,6 +523,7 @@ int gotoh_pair_wise_lgp ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
       
       for ( j=1; j<=lj; j++)
 	{
+	  
 	  gep[J]=gpl[J][GEP][j-1];
 	  gop[J]=gpl[J][GOP][j-1];
 	  gcp[J]=gpl[J][GCP][j-1];
@@ -478,16 +537,20 @@ int gotoh_pair_wise_lgp ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
 	  gcp[J]=(j==1 || j==lj )?0:gcp[J];
 	  
 	  
-	  sub=(CL->get_dp_cost) (A, pos0, ns[0], l_s[0], i-1, pos0, ns[1], l_s[1],j-1,CL);	
+	  //sub=(CL->get_dp_cost) (A, pos0, ns[0], l_s[0], i-1, pos0, ns[1], l_s[1],j-1,CL);	
+	  sub=TC_SCORE((i-1), (j-1));
 	  
 	  m[M1][i][j]=dp_max (&trace,3,M1,m[M1][i-1][j-1],I1, m[I1][i-1][j-1]+gcp[I],D1,m[D1][i-1][j-1]+gcp[J])+sub;
 	  t[M1][i][j]=trace;
 	  
+	  
 	  m[D1][i][j]=dp_max (&trace,2, M1,m[M1][i][j-1]+gop[J]+gep[J],D1, m[D1][i][j-1]+gep[J]);
 	  t[D1][i][j]=trace;
 	  
+	  
 	  m[I1][i][j]=dp_max (&trace,2, M1,m[M1][i-1][j]+gop[I]+gep[I],I1, m[I1][i-1][j]+gep[I]);
 	  t[I1][i][j]=trace;
+	  
 	}
 	  
     }
@@ -502,6 +565,8 @@ int gotoh_pair_wise_lgp ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
     {
   
       ntrace=t[trace][i][j];
+     
+      
       if (i==0)
 	{
 	  al[0][LEN]=0;
@@ -947,11 +1012,230 @@ int gotoh_pair_wise (Alignment *A,int*ns, int **l_s,Constraint_list *CL)
 	}
      
 
+int get_transition_cost (Alignment *A, int **posi, int ni, int *li, int i, int **posj, int nj, int *lj, int j,Constraint_list *CL);
+int gotoh_pair_wise_lgp_sticky ( Alignment *A, int *ns, int **l_s, Constraint_list *CL)
+{
+  int i,j, li, lj, n, sub, trace,ntrace, a, b, c, score;
+  int I, J;
+  int M1, I1, D1, LEN;
+  char **al, *char_buf, **aln;
+  int **pos0;
+  
+  int gop[2], gcp[2], gep[2];
+  static int ***gpl, ***t, ***m;
+  static int max_li, max_lj;
+  
+  
+
+  //gotoh_pair_wise ( A, ns, l_s,CL);
+  //ungap_sub_aln (A, ns[0], l_s[0]);
+  //ungap_sub_aln (A, ns[1], l_s[1]);
+  
+  I=0;J=1;
+
+  
+  li=strlen (A->seq_al[l_s[I][0]]);
+  lj=strlen (A->seq_al[l_s[J][0]]);
+  
+  if ( !gpl)gpl=vcalloc ( 2, sizeof (int**));
+  gpl[I]=aln2local_penalties (A,ns[I], l_s[I], CL,gpl[I]);
+  gpl[J]=aln2local_penalties (A,ns[J], l_s[J], CL,gpl[J]);
+  
+  
+  n=1;
+  M1=n++;D1=n++;I1=n++;
+  
+  if ( li>max_li ||lj>max_lj )
+    {
+      free_arrayN((void**)t, 3);
+      free_arrayN((void**)m, 3);
+
+     
+      max_li=li;
+      max_lj=lj;
+      t=declare_arrayN(3, sizeof (int),n, max_li+1, max_lj+1);
+      m=declare_arrayN(3, sizeof (int),n, max_li+1, max_lj+1);
+      
+    }
+  pos0=aln2pos_simple ( A,-1, ns, l_s);
+ 
+  
+  for (j=1; j<=lj; j++)
+    {
+      gep[J]=gpl[J][GEP][j-1];
+      m[D1][0][j]=gep[J]*j;
+      m[I1][0][j]=m[D1][0][j]-1;
+      m[M1][0][j]=m[D1][0][j]-1;
+    }
+  
+  //D1: gap in sequence I
+  //I1: gap in sequence J
+  
+  
+  for (i=1; i<=li; i++)
+    {
+      gep[I]=gpl[I][GEP][i-1];
+      gop[I]=gpl[I][GOP][i-1];
+      gcp[I]=gpl[I][GCP][i-1];
+      
+      m[I1][i][0]=i*gep[I];
+      m[D1][i][0]= m[I1][i][0]-1;
+      m[M1][i][0]= m[I1][i][0]-1;
+                 
+     
+      
+      gop[I]=(i==1 || i==li )?0:gop[I];
+      gcp[I]=(i==1 || i==li )?0:gcp[I];
+      
+      
+      for ( j=1; j<=lj; j++)
+	{
+	  int transition;
+	  
+	  gep[J]=gpl[J][GEP][j-1];
+	  gop[J]=gpl[J][GOP][j-1];
+	  gcp[J]=gpl[J][GCP][j-1];
+	  
+	  //gep[J]=gep[I]=(gep[J]+gep[I])/2;
+	  //gop[J]=gop[I]=(gop[J]+gop[I])/2;
+	  //gcp[J]=gcp[I]=(gcp[J]+gcp[I])/2;
+	  
+
+	  gop[J]=(j==1 || j==lj )?0:gop[J];
+	  gcp[J]=(j==1 || j==lj )?0:gcp[J];
+	  
+	  
+	  sub=(CL->get_dp_cost) (A, pos0, ns[0], l_s[0], i-1, pos0, ns[1], l_s[1],j-1,CL);
+	  transition=get_transition_cost (A, pos0, ns[0], l_s[0], i-1, pos0, ns[1], l_s[1],j-1,CL);
+
+	  m[M1][i][j]=dp_max (&trace,3,M1,m[M1][i-1][j-1]+transition,I1, m[I1][i-1][j-1]+gcp[I],D1,m[D1][i-1][j-1]+gcp[J])+sub;
+	  t[M1][i][j]=trace;
+	  
+	  
+	  m[D1][i][j]=dp_max (&trace,2, M1,m[M1][i][j-1]+gop[J]+gep[J],D1, m[D1][i][j-1]+gep[J]);
+	  t[D1][i][j]=trace;
+	  
+	  
+	  m[I1][i][j]=dp_max (&trace,2, M1,m[M1][i-1][j]+gop[I]+gep[I],I1, m[I1][i-1][j]+gep[I]);
+	  t[I1][i][j]=trace;
+	  
+	}
+	  
+    }
+  score=dp_max (&trace,3, M1,m[M1][li][lj],D1,m[D1][li][lj],I1, m[I1][li][lj]);
+  
+  LEN=0;i=li;j=lj;
+  al=declare_char (2, li+lj);
+  
+
+  trace=t[trace][i][j];
+  while (!(i==0 &&j==0))
+    {
+  
+      ntrace=t[trace][i][j];
+     
+      
+      if (i==0)
+	{
+	  al[0][LEN]=0;
+	  al[1][LEN]=1;
+	  j--;
+	  LEN++;
+	}
+      else if ( j==0)
+	{
+	  al[0][LEN]=1;
+	  al[1][LEN]=0;
+	  i--;
+	  LEN++;
+	}
+      else if ( trace==M1)
+	{
+	  al[0][LEN]=1;
+	  al[1][LEN]=1;
+	  i--; j--;
+	  LEN++;
+	}
+      else if ( trace==D1)
+	{
+	  al[0][LEN]=0;
+	  al[1][LEN]=1;
+	  j--;
+	  LEN++;
+	}
+      else if ( trace == I1)
+	{
+	  al[0][LEN]=1;
+	  al[1][LEN]=0;
+	  i--;
+	  LEN++;
+	}
+      trace=ntrace;     
+      
+    }
+  
+  invert_list_char ( al[0], LEN);
+  invert_list_char ( al[1], LEN);	
+  if ( A->declared_len<=LEN)A=realloc_aln  ( A,2*LEN+1);	
+  
+  aln=A->seq_al;
+  char_buf= vcalloc (LEN+1, sizeof (char));	
+  for ( c=0; c< 2; c++)
+    {
+      for ( a=0; a< ns[c]; a++) 
+	{		
+	  int ch=0;
+	  for ( b=0; b< LEN; b++)
+	    {		   
+	      if (al[c][b]==1)
+		char_buf[b]=aln[l_s[c][a]][ch++];
+	      else
+		char_buf[b]='-';
+	    }
+	  char_buf[b]='\0';
+	  sprintf (aln[l_s[c][a]],"%s", char_buf);
+	}
+    }
+  
+  
+  A->len_aln=LEN;
+  A->nseq=ns[0]+ns[1];
+  vfree (char_buf);
+  free_char (al, -1);
+  free_int (pos0, -1);
+  return score;
+}
+int get_transition_cost (Alignment *A, int **posi, int ni, int *li, int i, int **posj, int nj, int *lj, int j,Constraint_list *CL)
+{
+  /*counts the number of identical transitions between position i-1, i and j-1..j*/
+  float t=0;
+  int a,s;
+  Sequence *S;
+  
+  if (i==0 || j==0)return 0;
+  
+  for (a=0; a<ni; a++)
+    {
+      s=li[a];
+      if (posi[s][i]<0 || posi[s][i-1]<0)continue;
+      if (S->seq[li[a]][i-1]==S->seq[li[a]][i-1])t++;
+    }
+  
+  for (a=0; a<nj; a++)
+    {
+      s=lj[a];
+      if (posj[s][j]<0 || posj[s][j-1]<0)continue;
+      if (S->seq[li[a]][j-1]==S->seq[li[a]][j-1])t++;
+    }
+
+  t=(t*10)/(float)(ni+nj);
+  return t;
+}
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
