@@ -30,13 +30,11 @@ static int no_cross ();
 static int diff_sim( int *A,int *B,int M,int N,int tb,int te); 
 int calcons(int *aa0,int n0,int *aa1,int n1,int *res,int *nc,int *nident, Alignment *A, int *ns, int **l_s, Constraint_list *CL);
 
-#define TC_SCORE_2(x,y) (SCORE_K*CL->M[Aln->seq_al[l_s[0][0]][x]-'A'][Aln->seq_al[l_s[1][0]][y]-'A']-SCORE_K*CL->nomatch) 
-#define TC_SCORE_N(x,y) ((CL->get_dp_cost)(Aln, pos, ns[0], l_s[0], x, pos, ns[1], l_s[1], y, CL))
-#define TC_SCORE(x,y)  TC_SCORE_N(x,y)
+
 
 #define SIM_GAP -1
 #define min(x,y) ((x)<=(y) ? (x) : (y))
-
+//#define TC_SCORE_SIM(x,y) TC_SCORE (x,y)
 
 static int q, r;			/* gap penalties */
 static int qr;				/* qr = q + r */
@@ -535,7 +533,7 @@ int locate(int *A,int *B,int nseq)
 		  ORDER(d, di, dj, c, ci, cj)
 		  c = 0;
 		  DIAG(i, j, c, p+TC_SCORE(A[i-1],B[j-1]))		/* diagonal */
-		    
+		  
 		  if ( c <= 0 )
 		    { c = 0; ci = i; cj = j; }
 		  else
@@ -588,7 +586,7 @@ int locate(int *A,int *B,int nseq)
 		  ORDER(d, di, dj, c, ci, cj)
 		  c = 0;
 		  DIAG(m1, j, c, TC_SCORE(A[m1-1],B[j-1]))		/* diagonal */
-		    
+		 
 		  if ( c <= 0 )
 		    { c = 0; ci = m1; cj = j; }
 		  else
@@ -655,7 +653,8 @@ int locate(int *A,int *B,int nseq)
 		  ORDER(d, di, dj, c, ci, cj)
 		  c = 0;
 	          DIAG(i, n1, c, p+TC_SCORE(A[i-1], B[n1-1]))
-		    
+		 
+		   
 		  
 		  if ( c <= 0 )
 		    { c = 0; ci = i; cj = n1; }
@@ -750,7 +749,8 @@ int small_pass(int *A,int *B,int count,int nseq)
 		  ORDER(d, di, dj, c, ci, cj)
 		  c = 0;
 		  DIAG(i, j, c, p+TC_SCORE(A[i-1], B[j-1]))		/* diagonal */
-		    
+		    //checked
+
 		  if ( c <= 0 )
 		    { c = 0; ci = i; cj = j; }
 		  else
@@ -903,6 +903,7 @@ int diff_sim( int *A,int *B,int M,int N,int tb,int te)
 		{ tt = 0; break; }		
 	    if ( tt )			
 	      { c = TC_SCORE (A[0],B[j-1]) - ( gap(j-1) + gap(N-j) );
+		//checked
 		
 		if (c > midc)
 		  { midc = c;
@@ -951,7 +952,7 @@ int diff_sim( int *A,int *B,int M,int N,int tb,int te)
 	  { if ((c = c - qr) > (e = e - r)) e = c;
 	    if ((c = CC[j] - qr) > (d = DD[j] - r)) d = c;
 	    DIAG(i+I, j+J, c, s+TC_SCORE(A[i-1], B[j-1]))
-	      
+	      //checked
 	      
 	      if (c < d) c = d;
 	    if (c < e) c = e;
@@ -977,8 +978,8 @@ int diff_sim( int *A,int *B,int M,int N,int tb,int te)
 	for (j = N-1; j >= 0; j--)
 	  { if ((c = c - qr) > (e = e - r)) e = c;
 	    if ((c = RR[j] - qr) > (d = SS[j] - r)) d = c;
-	    DIAG(i+1+I, j+1+J, c, s+TC_SCORE(A[i],B[j])) /*not -1 on purpose*/
-	      
+	    DIAG(i+1+I, j+1+J, c, s+TC_SCORE (A[i],B[j])) /*not -1 on purpose*/
+	     
 	      if (c < d) c = d;
 	    if (c < e) c = e;
 	    s = RR[j];
@@ -1132,10 +1133,10 @@ void sim_free_all()
 }
   
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
