@@ -87,9 +87,8 @@ NT_node ** dist2nj_tree (double **distances, char **out_seq_name, int out_nseq,
 	double **d_dist;
 	int tot_node=0;
 
-	
-	if ( !tree_file)tree_file=vtmpnam(NULL);
 
+	if ( !tree_file)tree_file=vtmpnam(NULL);
 	d_dist=declare_double( out_nseq+1, out_nseq+1);
 	
 	for ( a=0; a<out_nseq; a++)
@@ -102,6 +101,7 @@ NT_node ** dist2nj_tree (double **distances, char **out_seq_name, int out_nseq,
 
 	guide_tree ( tree_file, d_dist, out_seq_name, out_nseq);
 	free_double (d_dist,-1);
+	
 	return read_tree (tree_file,&tot_node,out_nseq,  out_seq_name);	
 	}
 
@@ -1056,11 +1056,336 @@ void fast_nj_tree(char **tree_description)
 	ckfree(join);
 	ckfree(tvalid);
 }
+//////////////////////////////////////////////////////////////////////////////
+//
+//                              UPGMA_aln
+//////////////////////////////////////////////////////////////////////////////
+
+Alignment * upgma_merge_aln_rows  (Alignment***mat,int *used, int *n, int N, Constraint_list *CL);
+Alignment * upgma_merge_aln_pairs (Alignment *L, Alignment *R,Constraint_list *CL);
+
+Alignment * upgma_tree_aln  ( Alignment*A, int nseq, Constraint_list *CL)
+{
+  int a, b,c,n, *used;
+  Alignment *NA;
+  static Alignment ***mat;
+  
+  if (!mat)
+    {
+      Alignment *aln;
+
+      mat=declare_arrayN (2, sizeof ( Alignment *), A->nseq, A->nseq);
+      int **ls;
+      int *ns;
+      ls=declare_int (2, 2);
+      ns=vcalloc (2,sizeof (int));
+      ns[0]=ns[1]=1;
+      for (a=0; a<A->nseq; a++)
+	for (b=a; b<A->nseq; b++)
+	  {
+	  
+	    mat[a][b]=mat[b][a]=aln=seq2aln ((CL->S),NULL, RM_GAP);
+	    ls[0][0]=a;
+	    ls[1][0]=b;
+	    for (c=0; c<aln->nseq; c++)if (c!=a && c!=b)aln->seq_al[c][0]='\0'; 
+	    if (a!=b)
+	      {
+		pair_wise(aln, ns, ls, CL);
+	    	aln->score_aln=aln->score=sub_aln2sub_aln_score (aln, CL, CL->evaluate_mode,ns, ls);
+	      }
+	  }
+      free_int (ls, -1);
+      vfree (ns);
+    }
+  used=vcalloc (A->nseq, sizeof (int));
+  n=A->nseq;
+  while (n>1)
+    {
+      NA=upgma_merge_aln_rows (mat,used, &n, A->nseq, CL);
+    }    
+  print_aln (NA);
+  HERE ("finished");
+ 
+  return NA;
+}
+
+Alignment * upgma_merge_aln_rows (Alignment***mat,int *used, int *n, int N, Constraint_list *CL)
+{
+  
+  int a, b, w, best_a, best_b, set;
+  float best_s;
+    
+  for (set=0,a=0; a<N-1; a++)
+    {
+      if (used[a])continue;
+      for (b=a+1; b<N; b++)
+	{
+	  if (used[b])continue;
+	  w=(mat[a][b])->score_aln;
+	  if ( !set || w>best_s)
+	    {
+	      best_s=w;
+	      best_a=a;
+	      best_b=b;
+	      set=1;
+	    }
+	}
+    }
+  used[best_b]=1;
+  mat[best_a][best_a]=copy_aln(mat[best_a][best_b], NULL);
+  
+  for (a=0; a<N; a++)
+    {
+      if (used[a])continue;
+      mat[best_a][a]=mat[a][best_a]=upgma_merge_aln_pairs (mat[best_a][best_a],mat[a][a], CL);
+    }
+  HERE ("DONE");
+  
+  n[0]--;
+  return mat[best_a][best_a];
+}  
+Alignment * upgma_merge_aln_pairs (Alignment *L,Alignment *R, Constraint_list *CL)
+{
+  static int *ns;
+  static int **ls;
+  static Alignment *A;
+  int a;
+
+  if (!L || !R) return NULL;
+  if ( L==R) return L;
+  if (!ns)
+    {
+      ns=vcalloc ( 2, sizeof (int));
+      ls=declare_int (2, (CL->S)->nseq);
+    }
+  ns[0]=ns[1]=0;
+  A=seq2aln ((CL->S),NULL, RM_GAP);
+  A=copy_aln (L, A);
+
+  for (a=0; a<(CL->S)->nseq; a++)
+    {
+      A->seq_al[a][0]='\0';
+      if (L->seq_al[a][0])
+	{
+	  ls[0][ns[0]++]=a;
+	  sprintf (A->seq_al[a], "%s", L->seq_al[a]);
+	}
+      if (R->seq_al[a][0])
+	{
+	  ls[1][ns[1]++]=a;
+	  sprintf (A->seq_al[a], "%s", R->seq_al[a]);
+	}
+    }
+  pair_wise(A, ns, ls, CL);
+  A->score_aln=A->score=sub_aln2sub_aln_score (A, CL, CL->evaluate_mode,ns, ls);
+  return A;
+}
+//////////////////////////////////////////////////////////////////////////////
+//
+//                              UPGMA
+///////////////////////////////////////////////////////////////////////////////
+
+NT_node upgma_merge (int **mat, NT_node *NL, int *used, int *n, int N);
+NT_node ** int_dist2upgma_tree (int **mat, Alignment *A, int nseq, char *fname)
+{
+  NT_node *NL, T;
+  int a, n, *used;
+  NL=vcalloc (nseq, sizeof (NT_node));
+  for (a=0; a<A->nseq; a++)
+    {
+      NL[a]=new_declare_tree_node ();
+      sprintf (NL[a]->name, "%s", A->name[a]);
+      NL[a]->isseq=1;
+      NL[a]->leaf=1;
+    }
+    
+  used=vcalloc ( A->nseq, sizeof (int));
+  n=A->nseq;
+  while (n>1)
+    {
+      T=upgma_merge (mat, NL,used, &n, A->nseq);
+    }    
+
+  vfclose (print_tree (T, "newick", vfopen (fname, "w")));
+
+  return NULL;
+}
+NT_node upgma_merge (int **mat, NT_node *NL, int *used, int *n, int N)
+{
+  NT_node P, LC, RC;
+  int a, b, w, best_a, best_b, set;
+  float best_s;
+  P=new_declare_tree_node();
+    
+  for (set=0,a=0; a<N-1; a++)
+    {
+      if (used[a])continue;
+      for (b=a+1; b<N; b++)
+	{
+	  if (used[b])continue;
+	  w=mat[a][b];
+	  if ( !set || w<best_s)
+	    {
+	      best_s=w;
+	      best_a=a;
+	      best_b=b;
+	      set=1;
+	    }
+	}
+    }
+
+  for (a=0; a<N; a++)
+    {
+      if (!used[a])mat[best_a][a]=mat[a][best_a]=(mat[best_b][a]+mat[best_a][a])/2;
+    }
+  used[best_b]=1;
+  
+  LC=NL[best_a];
+  RC=NL[best_b];
+  best_s/=(float)100;
+  LC->dist=RC->dist=best_s;
+  LC->parent=RC->parent=P;
+  P->left=LC;
+  P->right=RC;
+  NL[best_a]=P;
+  n[0]--;
+  return P;
+
+}  
+
+
+//////////////////////////////////////////////////////////////////////////////
+//
+//                              SPLIT UPGMA
+///////////////////////////////////////////////////////////////////////////////
+
+NT_node split2upgma_tree (Split **S, Alignment *A, int nseq, char *fname)
+{
+  NT_node *NL, T;
+  int a, n, *used;
+  NL=vcalloc (nseq, sizeof (NT_node));
+  for (a=0; a<A->nseq; a++)
+    {
+      
+      NL[a]=new_declare_tree_node ();
+      NL[a]->lseq2=vcalloc (A->nseq+1, sizeof (int));
+      NL[a]->lseq2[a]=1;
+      sprintf (NL[a]->name, "%s", A->name[a]);
+      NL[a]->isseq=1;
+      NL[a]->leaf=1;
+      NL[a]->dist=1;
+    }
+  used=vcalloc ( A->nseq, sizeof (int));
+  n=A->nseq;
+  while (n>1)
+    {
+      T=split_upgma_merge (A,S, NL,used, &n, A->nseq);
+    }    
+  fprintf ( stdout, "\n");
+  vfclose (print_tree (T, "newick", vfopen (fname, "w")));
+
+  return T;
+}
+NT_node split_upgma_merge (Alignment *A, Split **S, NT_node *NL, int *used, int *n, int N)
+{
+  NT_node P, LC, RC;
+  int a, b, w, best_a, best_b, set;
+  float best_s;
+  static int **mat;
+
+  if (!mat)
+    {
+      mat=declare_int (N, N);
+      for (a=0; a<N-1; a++)
+	for ( b=a+1; b<N; b++)
+	  {
+	    mat[a][b]=get_split_dist (A, NL[a], NL[b], S);
+	  }
+    }
+
+  P=new_declare_tree_node();
+  P->lseq2=vcalloc (N, sizeof (int));
+  for (set=0,a=0; a<N-1; a++)
+    {
+      if (used[a])continue;
+      for (b=a+1; b<N; b++)
+	{
+	  if (used[b])continue;
+	  w=mat[a][b];
+	  if ( !set || w<best_s)
+	    {
+	      best_s=w;
+	      best_a=a;
+	      best_b=b;
+	      set=1;
+	    }
+	}
+    }
+
+  
+  
+  
+  LC=NL[best_a];
+  RC=NL[best_b];
+  best_s/=100;
+
+  P->dist=1-best_s;
+  LC->parent=RC->parent=P;
+  P->left=LC;
+  P->right=RC;
+  P->bootstrap=best_s*100;
+  used[best_b]=1;
+  
+  n[0]--;
+  
+  for (a=0; a<A->nseq; a++)
+    {
+      P->lseq2[a]=(LC->lseq2[a] || RC->lseq2[a])?1:0;
+    }
+  
+  for (a=0; a<N; a++)
+    {
+      if (!used[a])mat[best_a][a]=mat[a][best_a]=(int)get_split_dist(A,P, NL[a], S);
+    }
+  NL[best_a]=P;
+  
+  return P;
+
+}  
+float get_split_dist ( Alignment *A, NT_node L, NT_node R, Split **S) 
+{
+  static char *split;
+
+  
+  int n,a;
+  
+  if (!split)
+    {
+      split=vcalloc ( A->nseq+1, sizeof (char));
+    }
+  
+  
+  
+  for ( a=0; a<A->nseq; a++)
+    split[a]=((L->lseq2[a] || R->lseq2[a])?1:0)+'0';
+  
+  n=0;
+  while (S[n])
+    {
+      float score;
+      if ( strm (S[n]->split,split))
+	{
+	  return score=100-S[n]->score;
+	}
+      n++;
+    }
+  return 100;
+}
 /*********************************COPYRIGHT NOTICE**********************************/
-/* Centre National de la Recherche Scientifique (CNRS) */
+/* Centro de Regulacio Genomica */
 /*and */
 /*Cedric Notredame */
-/*Fri Oct 26 17:03:04     2007. */
+/*Fri Jun  6 17:35:06 WEST 2008. */
 /*All rights reserved.*/
 /*This file is part of T-COFFEE.*/
 /**/
